.. role:: hidden
    :class: hidden-section

Trainers
========

.. currentmodule:: sconce.trainer


:hidden:`Basic Trainer`
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: Trainer
    :members:


.. currentmodule:: sconce.trainers


:hidden:`AutoencoderTrainer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: AutoencoderTrainer
    :members:
    :show-inheritance:


:hidden:`ClassifierTrainer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: ClassifierTrainer
    :members:
    :show-inheritance:
